@@ -49,7 +49,7 @@ def clean_dataframe(df):
     dropped_rows = []
     for idx in df.index:
         local_time_str = df["Local_Time"][idx]
-        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or len(local_time_str.split('-')[0]) > 4:
+        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or len(local_time_str.split('-')[0]) > 4 or len(local_time_str.split(' ')) < 2:
             dropped_rows.append(idx)
     df = df.drop(dropped_rows)
 
